Index: Source/platform/fonts/skia/SimpleFontDataSkia.cpp |
diff --git a/Source/platform/fonts/skia/SimpleFontDataSkia.cpp b/Source/platform/fonts/skia/SimpleFontDataSkia.cpp |
index 748bed89c36b7bb1cf9d647b8fb77c1a10932e40..6f4912c38349fd5da09263797e539e6114e493e1 100644 |
--- a/Source/platform/fonts/skia/SimpleFontDataSkia.cpp |
+++ b/Source/platform/fonts/skia/SimpleFontDataSkia.cpp |
@@ -133,11 +133,19 @@ void SimpleFontData::platformInit() |
m_fontMetrics.setLineGap(lineGap); |
m_fontMetrics.setLineSpacing(lroundf(ascent) + lroundf(descent) + lroundf(lineGap)); |
- // For now Skia does not support underline Thickness, once patch is comitted we can uncomment following |
- // code, till then setting Underline Thickness to Zero so that default calculation is done. |
+ // FIXME: For now Skia does not support underline Thickness and Position, |
+ // once submitted patch is comitted (https://codereview.chromium.org/152073003/) |
+ // we can uncomment following code, till then setting Underline Thickness an d Position to Zero so that |
+ // default calculation is done. |
+ |
// float underlineThickness = SkScalarToFloat(metrics.fUnderlineThickness); |
// m_fontMetrics.setUnderlineThickness(underlineThickness); |
+ |
+ // float underlinePosition = SkScalarToFloat(metrics.fUnderlinePosition); |
+ // m_fontMetrics.setUnderlineThickness(underlinePosition); |
jungshik at Google
2014/03/06 01:05:32
Can you just wait for a Skia change to land and ro
|
+ |
m_fontMetrics.setUnderlineThickness(0.f); |
+ m_fontMetrics.setUnderlinePosition(0.f); |
if (platformData().orientation() == Vertical && !isTextOrientationFallback()) { |
static const uint32_t vheaTag = SkSetFourByteTag('v', 'h', 'e', 'a'); |